@@ -6,30 +6,31 @@ from jschon.vocabulary.annotation import *
 from jschon.vocabulary.applicator import *
 from jschon.vocabulary.core import *
 from jschon.vocabulary.format import *
+from jschon.vocabulary.legacy import *
 from jschon.vocabulary.validation import *
 
 
 def initialize(catalog: Catalog):
     catalog.add_uri_source(
-        URI('https://json-schema.org/draft/2020-12/'),
-        LocalSource(pathlib.Path(__file__).parent / 'json-schema-spec-2020-12', suffix='.json'),
+        URI('https://json-schema.org/draft/2019-09/'),
+        LocalSource(pathlib.Path(__file__).parent / 'json-schema-spec-2019-09', suffix='.json'),
     )
 
     catalog.create_vocabulary(
-        URI("https://json-schema.org/draft/2020-12/vocab/core"),
+        URI("https://json-schema.org/draft/2019-09/vocab/core"),
         SchemaKeyword,
         VocabularyKeyword,
         IdKeyword,
         RefKeyword,
         AnchorKeyword,
-        DynamicRefKeyword,
-        DynamicAnchorKeyword,
+        RecursiveRefKeyword_2019_09,
+        RecursiveAnchorKeyword_2019_09,
         DefsKeyword,
         CommentKeyword,
     )
 
     catalog.create_vocabulary(
-        URI("https://json-schema.org/draft/2020-12/vocab/applicator"),
+        URI("https://json-schema.org/draft/2019-09/vocab/applicator"),
         AllOfKeyword,
         AnyOfKeyword,
         OneOfKeyword,
@@ -38,23 +39,19 @@ def initialize(catalog: Catalog):
         ThenKeyword,
         ElseKeyword,
         DependentSchemasKeyword,
-        PrefixItemsKeyword,
-        ItemsKeyword,
+        ItemsKeyword_2019_09,
+        AdditionalItemsKeyword_2019_09,
+        UnevaluatedItemsKeyword_2019_09,
         ContainsKeyword,
         PropertiesKeyword,
         PatternPropertiesKeyword,
         AdditionalPropertiesKeyword,
+        UnevaluatedPropertiesKeyword,
         PropertyNamesKeyword,
     )
 
     catalog.create_vocabulary(
-        URI("https://json-schema.org/draft/2020-12/vocab/unevaluated"),
-        UnevaluatedItemsKeyword,
-        UnevaluatedPropertiesKeyword,
-    )
-
-    catalog.create_vocabulary(
-        URI("https://json-schema.org/draft/2020-12/vocab/validation"),
+        URI("https://json-schema.org/draft/2019-09/vocab/validation"),
         TypeKeyword,
         EnumKeyword,
         ConstKeyword,
@@ -78,12 +75,12 @@ def initialize(catalog: Catalog):
     )
 
     catalog.create_vocabulary(
-        URI("https://json-schema.org/draft/2020-12/vocab/format-annotation"),
+        URI("https://json-schema.org/draft/2019-09/vocab/format"),
         FormatKeyword,
     )
 
     catalog.create_vocabulary(
-        URI("https://json-schema.org/draft/2020-12/vocab/meta-data"),
+        URI("https://json-schema.org/draft/2019-09/vocab/meta-data"),
         TitleKeyword,
         DescriptionKeyword,
         DefaultKeyword,
@@ -94,19 +91,18 @@ def initialize(catalog: Catalog):
     )
 
     catalog.create_vocabulary(
-        URI("https://json-schema.org/draft/2020-12/vocab/content"),
+        URI("https://json-schema.org/draft/2019-09/vocab/content"),
         ContentMediaTypeKeyword,
         ContentEncodingKeyword,
         ContentSchemaKeyword,
     )
 
     catalog.create_metaschema(
-        URI("https://json-schema.org/draft/2020-12/schema"),
-        URI("https://json-schema.org/draft/2020-12/vocab/core"),
-        URI("https://json-schema.org/draft/2020-12/vocab/applicator"),
-        URI("https://json-schema.org/draft/2020-12/vocab/unevaluated"),
-        URI("https://json-schema.org/draft/2020-12/vocab/validation"),
-        URI("https://json-schema.org/draft/2020-12/vocab/format-annotation"),
-        URI("https://json-schema.org/draft/2020-12/vocab/meta-data"),
-        URI("https://json-schema.org/draft/2020-12/vocab/content"),
+        URI("https://json-schema.org/draft/2019-09/schema"),
+        URI("https://json-schema.org/draft/2019-09/vocab/core"),
+        URI("https://json-schema.org/draft/2019-09/vocab/applicator"),
+        URI("https://json-schema.org/draft/2019-09/vocab/validation"),
+        URI("https://json-schema.org/draft/2019-09/vocab/format"),
+        URI("https://json-schema.org/draft/2019-09/vocab/meta-data"),
+        URI("https://json-schema.org/draft/2019-09/vocab/content"),
     )
