@@ -2,7 +2,7 @@ class CatalogError(Exception):
     pass
 
 
-class JSONSchemaError(Exception):
+class JSONPatchError(Exception):
     pass
 
 
@@ -10,5 +10,13 @@ class JSONPointerError(Exception):
     pass
 
 
+class RelativeJSONPointerError(Exception):
+    pass
+
+
+class JSONSchemaError(Exception):
+    pass
+
+
 class URIError(Exception):
     pass
