@@ -51,7 +51,8 @@ class EnumKeyword(Keyword):
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if instance not in self.json:
-            scope.fail(f"The value must be one of {self.json}")
+            scope.fail("The instance value must be equal to one of the elements "
+                       "in the defined enumeration")
 
 
 class ConstKeyword(Keyword):
@@ -59,12 +60,12 @@ class ConstKeyword(Keyword):
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if instance != self.json:
-            scope.fail(f"The value must be equal to {self.json}")
+            scope.fail(f"The instance value must be equal to the defined constant")
 
 
 class MultipleOfKeyword(Keyword):
     key = "multipleOf"
-    types = "number"
+    types = "number",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         try:
@@ -76,7 +77,7 @@ class MultipleOfKeyword(Keyword):
 
 class MaximumKeyword(Keyword):
     key = "maximum"
-    types = "number"
+    types = "number",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if instance > self.json:
@@ -85,7 +86,7 @@ class MaximumKeyword(Keyword):
 
 class ExclusiveMaximumKeyword(Keyword):
     key = "exclusiveMaximum"
-    types = "number"
+    types = "number",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if instance >= self.json:
@@ -94,7 +95,7 @@ class ExclusiveMaximumKeyword(Keyword):
 
 class MinimumKeyword(Keyword):
     key = "minimum"
-    types = "number"
+    types = "number",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if instance < self.json:
@@ -103,7 +104,7 @@ class MinimumKeyword(Keyword):
 
 class ExclusiveMinimumKeyword(Keyword):
     key = "exclusiveMinimum"
-    types = "number"
+    types = "number",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if instance <= self.json:
@@ -112,7 +113,7 @@ class ExclusiveMinimumKeyword(Keyword):
 
 class MaxLengthKeyword(Keyword):
     key = "maxLength"
-    types = "string"
+    types = "string",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if len(instance) > self.json:
@@ -121,7 +122,7 @@ class MaxLengthKeyword(Keyword):
 
 class MinLengthKeyword(Keyword):
     key = "minLength"
-    types = "string"
+    types = "string",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if len(instance) < self.json:
@@ -130,7 +131,7 @@ class MinLengthKeyword(Keyword):
 
 class PatternKeyword(Keyword):
     key = "pattern"
-    types = "string"
+    types = "string",
 
     def __init__(self, parentschema: JSONSchema, value: str):
         super().__init__(parentschema, value)
@@ -143,7 +144,7 @@ class PatternKeyword(Keyword):
 
 class MaxItemsKeyword(Keyword):
     key = "maxItems"
-    types = "array"
+    types = "array",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if len(instance) > self.json:
@@ -152,7 +153,7 @@ class MaxItemsKeyword(Keyword):
 
 class MinItemsKeyword(Keyword):
     key = "minItems"
-    types = "array"
+    types = "array",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if len(instance) < self.json:
@@ -161,7 +162,7 @@ class MinItemsKeyword(Keyword):
 
 class UniqueItemsKeyword(Keyword):
     key = "uniqueItems"
-    types = "array"
+    types = "array",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if not self.json.data:
@@ -178,8 +179,8 @@ class UniqueItemsKeyword(Keyword):
 
 class MaxContainsKeyword(Keyword):
     key = "maxContains"
-    types = "array"
-    depends = "contains"
+    types = "array",
+    depends = "contains",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if contains := scope.sibling(instance, "contains"):
@@ -190,8 +191,8 @@ class MaxContainsKeyword(Keyword):
 
 class MinContainsKeyword(Keyword):
     key = "minContains"
-    types = "array"
-    depends = "contains", "maxContains"
+    types = "array",
+    depends = "contains", "maxContains",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if contains := scope.sibling(instance, "contains"):
@@ -213,7 +214,7 @@ class MinContainsKeyword(Keyword):
 
 class MaxPropertiesKeyword(Keyword):
     key = "maxProperties"
-    types = "object"
+    types = "object",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if len(instance) > self.json:
@@ -222,7 +223,7 @@ class MaxPropertiesKeyword(Keyword):
 
 class MinPropertiesKeyword(Keyword):
     key = "minProperties"
-    types = "object"
+    types = "object",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if len(instance) < self.json:
@@ -231,17 +232,17 @@ class MinPropertiesKeyword(Keyword):
 
 class RequiredKeyword(Keyword):
     key = "required"
-    types = "object"
+    types = "object",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
-        missing = [name for name in self.json if name.data not in instance]
+        missing = [name.value for name in self.json if name.data not in instance]
         if missing:
             scope.fail(f"The object is missing required properties {missing}")
 
 
 class DependentRequiredKeyword(Keyword):
     key = "dependentRequired"
-    types = "object"
+    types = "object",
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         missing = {}
